;; Generated package description from modus-themes.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "modus-themes" "4.7.0" "Elegant, highly legible and customizable themes" '((emacs "28.1")) :commit "d5a0eeb4f0fc5f865862465c6d17482d166b3b3d" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("faces" "theme" "accessibility") :url "https://github.com/protesilaos/modus-themes")
